pub enum ThemeCommand {
Show 17 variants
List {
discourse: String,
format: ListFormat,
verbose: bool,
},
Install {
discourse: String,
source: String,
branch: Option<String>,
},
Remove {
discourse: String,
name: String,
},
Delete {
discourse: String,
theme_id: u64,
},
Pull {
discourse: String,
theme_id: u64,
local_path: Option<PathBuf>,
},
Push {
discourse: String,
local_path: PathBuf,
theme_id: Option<u64>,
},
Duplicate {
discourse: String,
theme_id: u64,
format: ListFormat,
},
Show {
discourse: String,
theme_id: u64,
format: ListFormat,
},
Setting {
command: ThemeSettingCommand,
},
Enable {
discourse: String,
theme_id: u64,
},
Disable {
discourse: String,
theme_id: u64,
},
Attach {
discourse: String,
parent_id: u64,
component_id: u64,
},
Detach {
discourse: String,
parent_id: u64,
component_id: u64,
},
Field {
command: ThemeFieldCommand,
},
Asset {
command: ThemeAssetCommand,
},
Update {
discourse: String,
theme_id: u64,
check: bool,
},
Palette {
command: PaletteCommand,
},
}Variants
List
List installed themes.
Fields
format: ListFormatOutput format.
Install
Install a theme from a git repo or a local bundle file (via the API).
Fields
Remove
Remove a theme by name (SSH rake). Prefer theme delete <id> (API).
Delete
Delete a theme/component by id via the API. Honours --dry-run.
Pull
Pull a theme to a local JSON file.
Fields
Push
Push a local JSON file to create or update a theme.
Fields
Duplicate
Duplicate a theme and print the new theme ID.
Fields
format: ListFormatOutput format.
Show
Show a richer view of one theme/component than list.
Fields
format: ListFormatOutput format.
Setting
Read and write a theme/component’s settings (not site settings).
Fields
command: ThemeSettingCommandEnable
Enable a theme or component.
Disable
Disable a theme or component.
Attach
Attach a component to a parent theme (makes it active on that theme).
Fields
Detach
Detach a component from a parent theme.
Fields
Field
Read/write individual theme fields (SCSS, head_tag, …).
Fields
command: ThemeFieldCommandAsset
Upload and bind theme-scoped image/font assets ($var).
Fields
command: ThemeAssetCommandUpdate
Pull a git-backed remote component to its latest upstream commit.
Fields
Palette
Manage colour palettes (colour schemes). The canonical home for what
was dsc palette.
Fields
command: PaletteCommandTrait Implementations
Sourceimpl FromArgMatches for ThemeCommand
impl FromArgMatches for ThemeCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Subcommand for ThemeCommand
impl Subcommand for ThemeCommand
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Self can parse a specific subcommand