pub enum TopicCommand {
Pull {
discourse: String,
topic_id: u64,
local_path: Option<PathBuf>,
full: bool,
},
Push {
discourse: String,
topic_id: u64,
local_path: PathBuf,
},
Sync {
discourse: String,
topic_id: u64,
local_path: PathBuf,
yes: bool,
},
Reply {
discourse: String,
topic_id: u64,
local_path: Option<PathBuf>,
},
New {
discourse: String,
category_id: u64,
title: String,
local_path: Option<PathBuf>,
},
Tag {
discourse: String,
topic_id: u64,
tag: String,
},
Untag {
discourse: String,
topic_id: u64,
tag: String,
},
}Variants
Pull
Pull a topic to a local Markdown file.
Fields
Push
Push a local Markdown file to a topic.
Fields
Sync
Sync a topic and local Markdown file using newest timestamp.
Fields
Reply
Reply to a topic with content from a file or stdin.
Fields
New
Create a new topic in a category, body from a file or stdin.
Fields
Tag
Add a tag to a topic.
Untag
Remove a tag from a topic.